==> haskell-dense-linear-algebra-0.1.0.0-436.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dense-linear-algebra
version:              0.1.0.0
visibility:           public
id:                   dense-linear-algebra-0.1.0.0-1wrl8rDvQisAHTzvG1CjRq
key:                  dense-linear-algebra-0.1.0.0-1wrl8rDvQisAHTzvG1CjRq
license:              BSD-2-Clause
copyright:            2018 Author name here
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
synopsis:
    Simple and incomplete pure haskell implementation of linear algebra

description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.

category:             Math, Statistics, Numeric
abi:                  7bd3e5e88a3dd8c9ae276260a53fa81f
exposed:              True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dense-linear-algebra-0.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dense-linear-algebra-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dense-linear-algebra
hs-libraries:         HSdense-linear-algebra-0.1.0.0-1wrl8rDvQisAHTzvG1CjRq
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    math-functions-0.3.4.4-LDnJq54zodn2casmhUMe9e
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP
    vector-algorithms-0.9.1.0-nPezpE6T5gHv4BTs4clf9
    vector-binary-instances-0.2.5.2-LMaYNjTJVg9Be5d5O1SNoZ
    vector-th-unbox-0.2.2-ImcSwt94EHZJi6PFnaUEjq

haddock-interfaces:
    /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock

haddock-html:         /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dense-linear-algebra-0.1.0.0-437-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dense-linear-algebra
version:              0.1.0.0
visibility:           public
id:                   dense-linear-algebra-0.1.0.0-HaeAShArlbhFHVOCNTtlvk
key:                  dense-linear-algebra-0.1.0.0-HaeAShArlbhFHVOCNTtlvk
license:              BSD-2-Clause
copyright:            2018 Author name here
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
synopsis:
    Simple and incomplete pure haskell implementation of linear algebra

description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.

category:             Math, Statistics, Numeric
abi:                  e1746c1ab76391f6ca38b31fc70393c5
exposed:              True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dense-linear-algebra-0.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dense-linear-algebra-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dense-linear-algebra
hs-libraries:         HSdense-linear-algebra-0.1.0.0-HaeAShArlbhFHVOCNTtlvk
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    math-functions-0.3.4.4-ISK9KPJw6XgFAhCTgWxhOZ
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH
    vector-algorithms-0.9.1.0-GdPL2rq4cry7HNPKxZ4cz0
    vector-binary-instances-0.2.5.2-DefExvwOSIi1i0IrJrD1MU
    vector-th-unbox-0.2.2-HC5jNvwwS6Y1jBxTSVdusQ

haddock-interfaces:
    /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock

haddock-html:         /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
